# User Guide: Core Features

Welcome to the main User Guide. This section covers the 80% of features you will use daily to structure, configure, and manage your components.

---

## 📖 Table of Contents

* [1. Core Concepts: `@component`, `@factory`, `@provides`](./core-concepts.md)
* [2. Configuration: Basic Concepts](./configuration-basic.md)
* [3. Configuration: Binding Data (`@configured`)](./configuration-binding.md)
* [4. Scopes, Lifecycle & `lazy`](./scopes-lifecycle.md)
* [5. Qualifiers & List Injection](./qualifiers-lists.md)
* [6. Testing Applications](./testing.md)
* [7. Extending Component Discovery (CustomScanner)](../advanced-features/custom-scanners.md)
